//-*-c++-*-
/*
 Author: David Auber
 Email : auber@labri.fr
 Last modification : 20/08/2001
 This program is free software; you can redistribute it and/or modify  *
 it under the terms of the GNU General Public License as published by  
 the Free Software Foundation; either version 2 of the License, or     
 (at your option) any later version.
*/

#ifndef _METAGRAPH_H
#define _METAGRAPH_H

#include "Types.h"
#include "Property.h"

class PropertyContext;
class MetaGraphProxy;
/** \addtogroup plugins */ 
/*@{*/

/// Interface for metric plug-ins
class MetaGraph:public Property<MetaGraphType , MetaGraphType>
{ 
  ///
  friend class MetaGraphProxy;
public:
  /** This metagraph proxy is the one associated to the plug-ins,
    *  The data should be store in it
    */
  MetaGraphProxy *metaGraphProxy;
protected:
  ///
  MetaGraph (const PropertyContext & context);
  ///
  virtual ~MetaGraph(){}
};

/*@}*/
#endif

